@@ -4,7 +4,7 @@
 ****************************************************************************
  uninstall.py, Linux uninstall script for TreeLine
 
- Copyright (C) 2003, Douglas W. Bell
+ Copyright (C) 2013, Douglas W. Bell
 
  This is free software; you can redistribute it and/or modify it under the
  terms of the GNU General Public License, either Version 2 or any later
@@ -20,39 +20,44 @@ import shutil
 
 prefixDir = '/usr/local'
 progName = 'treeline'
-hasData = 0
 
 def usage(exitCode=2):
-    """Display usage info and exit"""
+    """Display usage info and exit.
+
+    Arguments:
+        exitCode -- the code to retuen when exiting.
+    """
     global prefixDir
-    print 'Usage:'
-    print '    python uninstall.py [-h] [-p dir]'
-    print 'where:'
-    print '    -h         display this help message'
-    print '    -p dir     install prefix [default: %s]' % prefixDir
+    print('Usage:')
+    print('    python uninstall.py [-h] [-p dir]')
+    print('where:')
+    print('    -h         display this help message')
+    print('    -p dir     install prefix [default: {0}]'.format(prefixDir))
     sys.exit(exitCode)
 
 def removeAll(path):
     """Remove path, whether it is a file or a directory,
        print status"""
-    print '  Removing %s...' % path,
+    print('  Removing {0}...'.format(path))
     try:
         if os.path.isdir(path):
             shutil.rmtree(path)
         elif os.path.isfile(path):
             os.remove(path)
         else:
-            print '  not found'
+            print('  not found')
             return
-        print '  done'
-    except OSError, e:
+        print('  done')
+    except OSError as e:
         if str(e).find('Permission denied') >= 0:
-            print '\nError - must be root to remove files'
+            print('\nError - must be root to remove files')
             sys.exit(4)
         raise
 
 
 def main():
+    """Main uninstaller function.
+    """
     try:
         opts, args = getopt.getopt(sys.argv[1:], 'hp:')
     except getopt.GetoptError:
@@ -63,18 +68,14 @@ def main():
             usage(0)
         elif opt == '-p':
             prefixDir = val
-    print 'Removing files...'
+    print('Removing files...')
     global progName
     removeAll(os.path.join(prefixDir, 'lib', progName))
     removeAll(os.path.join(prefixDir, 'share', 'doc', progName))
-    global hasData
-    if hasData:
-        removeAll(os.path.join(prefixDir, 'share', progName))
+    removeAll(os.path.join(prefixDir, 'share', progName))
     removeAll(os.path.join(prefixDir, 'share', 'icons', progName))
-    removeAll(os.path.join(prefixDir, 'share', 'icons', '%s_lg.png' % progName))
-    removeAll(os.path.join(prefixDir, 'share', 'icons', '%s_sm.png' % progName))
     removeAll(os.path.join(prefixDir, 'bin', progName))
-    print 'Uninstall complete.'
+    print('Uninstall complete.')
 
 
 if __name__ == '__main__':
